@@ -356,110 +356,9 @@ def reformat_dbscan_results ( results:dict ) -> dict :
                         clusters[ icontent ] = [ c[1] ]
         return ( clusters )
 
-def unpack ( seq ) : # seq:Union -> Union
-    if isinstance ( seq,(list,tuple,set)) :
-        yield from ( x for y in seq for x in unpack(y) )
-    elif isinstance ( seq , dict ):
-        yield from ( x for item in seq.items() for y in item for x in unpack(y) )
-    else :
-        yield seq
-
-def rem ( a:list , H:list ) -> list :
-    h0 = []
-    for h in H:
-        hp = h - np.sum(h>np.array(h0))
-        h0 .append(h)
-        a .pop(hp)
-    return(a)
-
-def linkage ( distm:np.array , command:str = 'max' ) -> dict :
-    #
-    # CALUCULATES WHEN SAIGAS ARE LINKED
-    # MAX CORRESPONDS TO COMPLETE LINKAGE
-    # MIN CORRESPONDS TO SINGLE LINKAGE
-    #
-    D = distm
-    N = len(D)
-
-    sidx = [ str(i)+'-'+str(j) for i in range(N) for j in range(N) if i<j ]
-    pidx = [ [i,j] for i in range(N) for j in range(N) if i<j ]
-    R = [ D[idx[0]][idx[1]] for idx in pidx ]
-
-    label_order = lambda i,k: i+'-'+k if '.' in i else k+'-'+i if '.' in k else  i+'-'+k if int(i)<int(k) else k+'-'+i
-
-    if command == 'max':
-        func  = lambda R,i,j : [(R[i],i),(R[j],j)] if R[i]>R[j] else [(R[j],j),(R[i],i)]
-    if command == 'min':
-        func  = lambda R,i,j : [(R[i],i),(R[j],j)] if R[i]<R[j] else [(R[j],j),(R[i],i)]
-
-    LINKS = {}
-    cleared = set()
-
-    for I in range( N**2 ) : # WORST CASE SCENARIO
-
-        clear = []
-        if len(R) == 0 :
-            break
-
-        nar   = np.argmin( R )
-        clu_idx = sidx[nar].replace('-','.')
-
-        LINKS = { **{ clu_idx : R[nar] } , **LINKS }
-        lp    = {}
-
-        for l in range(len(sidx)) :
-            lidx = sidx[l]
-            lp [ lidx ] = l
-
-        pij   = sidx[nar].split('-')
-        cidx  = set( unpack( [ s.split('-') for s in [ s for s in sidx if len(set(s.split('-'))-set(pij)) == 1 ] ] ) )-set(pij)
-        ccidx = set( [ s for s in [ s for s in sidx if len(set(s.split('-'))-set(pij)) == 1 ] ] )
-        found = {}
-
-        i   = pij[0]
-        j   = pij[1]
-
-        for k in cidx :
-            h0 , h1 , h2 , q0, J = None , None , None , None, 0
-            if k == j or k == i :
-                continue
-            la1 = label_order(i,k)
-            if la1 in lp :
-                J+=1
-                h1 = lp[ label_order(i,k) ]
-                h0 = h1 ; q0 = i
-            la2 = label_order(j,k)
-            if la2 in lp :
-                J+=1
-                h2 = lp[ label_order(j,k) ]
-                h0 = h2 ; q0 = j
-            if J == 2 :
-                Dijk = func ( R , h1 , h2 )
-            elif J == 1 :
-                Dijk = [[ R[h0],h0 ]]
-            else :
-                continue
-            nidx = [ s for s in sidx[Dijk[0][1]].split('-') ]
-            nidx = list( set(sidx[Dijk[0][1]].split('-'))-set(pij) )[0]
-            nclu_idx = clu_idx + '-' + nidx
-            found[ nclu_idx ] = Dijk[0][0]
-
-        clear = [*[ lp[c] for c in ccidx ],*[nar]]
-        cleared = cleared | set( unpack( [ sidx[c].split('-') for c in clear ]) )
-
-        R = rem(R,clear)
-        sidx = rem(sidx,clear)
-
-        for label,d in found.items() :
-            R.append(d)
-            sidx.append(label)
-
-    return ( LINKS )
-
-
 if __name__=='__main__' :
-
-    D = [[0,9,3,6,11],[9,0,7,5,10],[3,7,0,9,2],[6,5,9,0,8],[11,10,2,8,0] ]
-    print ( np.array(D) )
-    print ( 'min>' , linkage( D, command='min') )
-    print ( 'max>' , linkage( D, command='max') )
+    # NOW CALLED LINAKGES IN HIERARCHICAL
+    #D = [[0,9,3,6,11],[9,0,7,5,10],[3,7,0,9,2],[6,5,9,0,8],[11,10,2,8,0] ]
+    #print ( np.array(D) )
+    #print ( 'min>' , linkage( D, command='min') )
+    #print ( 'max>' , linkage( D, command='max') )
